netapp_ontap.models.consistency_group_snaplock API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_snaplock`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupSnaplockSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupSnaplock object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `compliance_clock_time: ImpreciseDateTime GET`

    The compliance clock time used to manage the SnapLock objects in the consistency group.

    Example: 2018-06-04T19:00:00.000+0000

  `expiry_time: ImpreciseDateTime GET`

    Expiry time of the consistency group. For consistency group with an infinite SnapLock expiry time, "9999-12-31T23:59:59" is used to denote the time.

    Example: 2018-06-04T19:00:00.000+0000

  `retention: ConsistencyGroupSnaplockRetention GET POST PATCH`

    The retention value represents a duration and must be specified in the ISO-8601 duration format. The retention period can be in years, months, days, hours, and minutes. A duration specified for years, months, and days is represented in the ISO-8601 format as "PY", "PM", "PD" respectively, for example "P10Y" represents a duration of 10 years. A duration in hours and minutes is represented by "PTH" and "PTM" respectively. The retention string must contain only a single time element that is, either years, months, days, hours, or minutes. A duration which combines different periods is not supported, for example "P1Y10M" is not supported. Apart from the duration specified in the ISO-8601 format, the duration field also accepts the string "infinite" to set an infinite retention period and the string "unspecified" to set an unspecified retention period.

  `type: str GET`

    The SnapLock type of the consistency group.
    compliance ‐ A SnapLock Compliance (SLC) consistency group provides the highest level of WORM protection and an administrator cannot destroy an SLC consistency group if it contains unexpired WORM objects.
    enterprise ‐ An administrator can delete a SnapLock Enterprise (SLE) consistency group.
    non_snaplock ‐ Indicates the consistency group is non-snaplock.

    Valid choices:

    - compliance
    - enterprise
    - non_snaplock